pub struct Predicate {
pub kind: PredicateKind,
pub span: Range<usize>,
}Expand description
One node of a parsed predicate and the byte range of its text.
Fields
kind: PredicateKindWhat the node is.
span: Range<usize>Its text’s byte range in the predicate, enclosing parentheses included.
Implementations