pub fn template_text_from_value(
value: &Value,
options: &TileOptions,
) -> Result<String, String>Expand description
Turn a structural template into template text under options.
The text is what an author would have written in a tile ... : json
block for the same document.